@@ -12,7 +12,9 @@
 #include <cmath> 
 #include <R_ext/Error.h>
 #include <R_ext/Print.h>
-//#include <Rinternals.h>
+#include <Rinternals.h>
+#undef error
+#undef length
 //#include <Eigen/Dense>
 
 #include "EpochSimulation.h"
@@ -24,9 +26,6 @@
 #include "model/variables/ContinuousVariable.h"
 #include "utils/Random.h"
 
-#include <Rinternals.h>
-
-
 namespace siena
 {
 /**
@@ -45,7 +44,7 @@ SdeSimulation::SdeSimulation(EpochSimulation * pSimulation)
 	
 	if (nContinuous > 1)
 	{
-		error("More than one continuous dependent variable: not implemented");
+		Rf_error("More than one continuous dependent variable: not implemented");
 	}
 	// for (unsigned i = 0; i < pSimulation->rcontinuousVariables.size(); i++) {
 
