@@ -39,12 +39,16 @@ class EffectInfo;
 class EffectFactory
 {
 public:
+	static const std::string gmmGroup(const EffectInfo* pEffectInfo);
+
 	EffectFactory(const Data * pData);
 
 	Effect * createEffect(const EffectInfo * pEffectInfo) const;
 
 private:
 	const Data * lpData;
+	static const std::map<const std::string, const std::string> GMM_GROUPS;
+	static std::map<const std::string, const std::string> init_groups();
 };
 
 }
