@@ -11,7 +11,9 @@
 #include <stdexcept>
 #include <string>
 #include <cmath>
-//#include <Rinternals.h>
+#include <Rinternals.h>
+#undef error
+#undef length
 #include "MLSimulation.h"
 #include "utils/Random.h"
 #include "utils/Utils.h"
@@ -30,7 +32,6 @@
 #include "model/ml/NetworkChange.h"
 #include "model/ml/BehaviorChange.h"
 #include "model/tables/Cache.h"
-#include <Rinternals.h>
 
 using namespace std;
 
