@@ -13,8 +13,6 @@
 #define SIENA07INTERNALS_H_
 
 #include <Rinternals.h>
-#undef error
-#undef length
 #include <vector>
 
 namespace siena
